﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Timers;
using PRISMResourceTest.Infrastructure.Helpers;

namespace PRISMResourceTest.MainModule.ViewModels
{
    /// <summary>
    /// Basic ViewModel to prove "normal" binding still works
    /// </summary>
    public class MainScreenViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected void RaisePropertyChanged(string propertyName)
        {
            var evt = PropertyChanged;

            if (evt != null)
                evt.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        private string _CurrentTime;
        /// <summary>
        /// Basic text property that shows the current time
        /// 
        /// Timer is used to update it every second
        /// </summary>
        public string CurrentTime
        {
            get
            {
                return _CurrentTime;
            }
            private set
            {
                _CurrentTime = value;
                RaisePropertyChanged("CurrentTime");
            }
        }

        /// <summary>
        /// Initializes a new instance of the MainScreenViewModel class.
        /// </summary>
        public MainScreenViewModel()
        {
            // Don't run the timer if we are in design mode
            if (!DesignHelpers.IsInDesignModeStatic)
            {
                // Kickoff a timer to update the time every second
                var updateTimer = new Timer(1000);
                updateTimer.Elapsed += (s, e) => { CurrentTime = DateTime.Now.ToLongTimeString(); };
                updateTimer.AutoReset = true;
                updateTimer.Start();
            }

            CurrentTime = DateTime.Now.ToLongTimeString();
        }
    }
}
