﻿using System;
using Microsoft.Practices.Composite.UnityExtensions;
using Microsoft.Practices.Composite.Modularity;
using System.IO;
using PRISMResourceTest.Infrastructure.Services;
using Microsoft.Practices.Unity;
using System.Windows;
using PRISMResourceTest.Shell.Views;

namespace PRISMResourceTest.Shell
{
    public class BootStrapper : UnityBootstrapper
    {
        private const string MODULE_PATH = @".";

        protected override void ConfigureContainer()
        {
            // Register our ShellView
            Container.RegisterType<IShellProvider, ShellView>(new ContainerControlledLifetimeManager());
            base.ConfigureContainer();
        }

        protected override IModuleCatalog GetModuleCatalog()
        {
            IModuleCatalog catalog;

            // Use a DirectoryModuleCatalog if our module directory exists
            if (Directory.Exists(MODULE_PATH))
                catalog = new DirectoryModuleCatalog() { ModulePath = MODULE_PATH };
            else
                catalog = new ModuleCatalog();

            return catalog;
        }

        protected override DependencyObject CreateShell()
        {
            // Use the container to create an instance of the shell.
            var shellProvider = Container.Resolve<IShellProvider>();

            // Display the Shell as the root visual for the application.
            UIElement shell = shellProvider.CreateShell();

            return shell;
        }
    }
}
